EXPORTS
	??1DTraceCoreSubscriber@@UAE@XZ @ 1 NONAME ; DTraceCoreSubscriber::~DTraceCoreSubscriber(void)
	?WriteStart@DTraceCoreMediaSWriter@@EAEKW4TWriterEntryType@@@Z @ 2 NONAME ; unsigned long DTraceCoreMediaSWriter::WriteStart(enum TWriterEntryType)
	?IsTraceActivated@DTraceActivationIf@@SAHKK@Z @ 3 NONAME ; int DTraceActivationIf::IsTraceActivated(unsigned long, unsigned long)
	??0DTraceCoreSubscriber@@QAE@XZ @ 4 NONAME ; DTraceCoreSubscriber::DTraceCoreSubscriber(void)
	?GetSet@DTraceCoreOstLddIf@@SAKW4TTraceCoreOstLddIfGetSet@@K@Z @ 5 NONAME ; unsigned long DTraceCoreOstLddIf::GetSet(enum TTraceCoreOstLddIfGetSet, unsigned long)
	?GetInstance@DTraceCore@@SAPAV1@XZ @ 6 NONAME ; class DTraceCore * DTraceCore::GetInstance(void)
	?AddCategory@DBTraceCategoryHandler@@QAEHE@Z @ 7 NONAME ; int DBTraceCategoryHandler::AddCategory(unsigned char)
	?Subscribe@DTraceCoreSubscriber@@QAEHK@Z @ 8 NONAME ; int DTraceCoreSubscriber::Subscribe(unsigned long)
	?IsLoaded@DTraceCore@@SAHXZ @ 9 NONAME ; int DTraceCore::IsLoaded(void)
	??1DTraceCoreSettings@@UAE@XZ @ 10 NONAME ; DTraceCoreSettings::~DTraceCoreSettings(void)
	??1DTraceCoreMediaSWriter@@UAE@XZ @ 11 NONAME ; DTraceCoreMediaSWriter::~DTraceCoreMediaSWriter(void)
	?Register@DTraceCoreWriter@@UAEHXZ @ 12 NONAME ; int DTraceCoreWriter::Register(void)
	?Register@DTraceCoreMediaPlugin@@QAEHXZ @ 13 NONAME ; int DTraceCoreMediaPlugin::Register(void)
	??0DBTraceCategoryHandler@@QAE@XZ @ 14 NONAME ; DBTraceCategoryHandler::DBTraceCategoryHandler(void)
	?SetWriter@DBTraceCategoryHandler@@UAEXPAVDTraceCoreWriter@@@Z @ 15 NONAME ; void DBTraceCategoryHandler::SetWriter(class DTraceCoreWriter *)
	?Register@DTraceCoreMediaSWriter@@UAEHXZ @ 16 NONAME ; int DTraceCoreMediaSWriter::Register(void)
	?Register@DBTraceCategoryHandler@@QAEHXZ @ 17 NONAME ; int DBTraceCategoryHandler::Register(void)
	?WriteData@DTraceCoreMediaSWriter@@EAEXKE@Z @ 18 NONAME ; void DTraceCoreMediaSWriter::WriteData(unsigned long, unsigned char)
	?Subscribe@DTraceCoreSubscriber@@QAEHKW4TMessageHeaderFormat@@@Z @ 19 NONAME ; int DTraceCoreSubscriber::Subscribe(unsigned long, enum TMessageHeaderFormat)
	?PrepareSetWriter@DBTraceCategoryHandler@@UAEXPAVDTraceCoreWriter@@@Z @ 20 NONAME ; void DBTraceCategoryHandler::PrepareSetWriter(class DTraceCoreWriter *)
	?MessageReceived@DTraceCoreMediaPlugin@@QAEXAAVTTraceMessage@@@Z @ 21 NONAME ; void DTraceCoreMediaPlugin::MessageReceived(class TTraceMessage &)
	??0DTraceCoreWriter@@QAE@W4TWriterType@@@Z @ 22 NONAME ; DTraceCoreWriter::DTraceCoreWriter(enum TWriterType)
	?UnregisterNotificationReceiver@MTraceCoreNotificationReceiver@@QAEXK@Z @ 23 NONAME ; void MTraceCoreNotificationReceiver::UnregisterNotificationReceiver(unsigned long)
	?TraceError@MTraceCoreNotificationReceiver@@UAEXKKH@Z @ 24 NONAME ; void MTraceCoreNotificationReceiver::TraceError(unsigned long, unsigned long, int)
	??1MTraceCoreNotificationReceiver@@UAE@XZ @ 25 NONAME ; MTraceCoreNotificationReceiver::~MTraceCoreNotificationReceiver(void)
	?DeactivateTrace@DTraceActivationIf@@SAXKK@Z @ 26 NONAME ; void DTraceActivationIf::DeactivateTrace(unsigned long, unsigned long)
	?WriteData@DTraceCoreMediaSWriter@@EAEXKG@Z @ 27 NONAME ; void DTraceCoreMediaSWriter::WriteData(unsigned long, unsigned short)
	?RegisterNotificationReceiver@MTraceCoreNotificationReceiver@@QAEHKJ@Z @ 28 NONAME ; int MTraceCoreNotificationReceiver::RegisterNotificationReceiver(unsigned long, long)
	?Unsubscribe@DTraceCoreSubscriber@@QAEXK@Z @ 29 NONAME ; void DTraceCoreSubscriber::Unsubscribe(unsigned long)
	?MergeHeaderAndData@DTraceCoreMediaPlugin@@QAEHABVTTraceMessage@@AAVTDes8@@@Z @ 30 NONAME ; int DTraceCoreMediaPlugin::MergeHeaderAndData(class TTraceMessage const &, class TDes8 &)
	?WriteTraceCoreFrame@DTraceCoreWriter@@UAEXKKKKKKKKKKK@Z @ 31 NONAME ; void DTraceCoreWriter::WriteTraceCoreFrame(unsigned long, unsigned long, unsigned long, unsigned long, unsigned long, unsigned long, unsigned long, unsigned long, unsigned long, unsigned long, unsigned long)
	??0DTraceCoreMediaPlugin@@QAE@XZ @ 32 NONAME ; DTraceCoreMediaPlugin::DTraceCoreMediaPlugin(void)
	?DestroyTraceCore@DTraceCore@@SAXXZ @ 33 NONAME ; void DTraceCore::DestroyTraceCore(void)
	?GetSet@DTraceCoreConfiguration@@SAKW4TTraceCoreConfiguration@@K@Z @ 34 NONAME ; unsigned long DTraceCoreConfiguration::GetSet(enum TTraceCoreConfiguration, unsigned long)
	?Register@DTraceCoreSettings@@QAEHXZ @ 35 NONAME ; int DTraceCoreSettings::Register(void)
	??1DBTraceCategoryHandler@@UAE@XZ @ 36 NONAME ; DBTraceCategoryHandler::~DBTraceCategoryHandler(void)
	?WriteData@DTraceCoreMediaSWriter@@EAEXKK@Z @ 37 NONAME ; void DTraceCoreMediaSWriter::WriteData(unsigned long, unsigned long)
	?SetSettings@DBTraceCategoryHandler@@UAEXPAVDTraceCoreSettings@@@Z @ 38 NONAME ; void DBTraceCategoryHandler::SetSettings(class DTraceCoreSettings *)
	??1DTraceCoreWriter@@UAE@XZ @ 39 NONAME ; DTraceCoreWriter::~DTraceCoreWriter(void)
	?WriteEnd@DTraceCoreMediaSWriter@@EAEXK@Z @ 40 NONAME ; void DTraceCoreMediaSWriter::WriteEnd(unsigned long)
	?SwitchToWriter@DTraceCore@@QAEHW4TWriterType@@@Z @ 41 NONAME ; int DTraceCore::SwitchToWriter(enum TWriterType)
	?RegisterNotificationReceiver@MTraceCoreNotificationReceiver@@QAEHK@Z @ 42 NONAME ; int MTraceCoreNotificationReceiver::RegisterNotificationReceiver(unsigned long)
	?ActivateTrace@DTraceActivationIf@@SAXKK@Z @ 43 NONAME ; void DTraceActivationIf::ActivateTrace(unsigned long, unsigned long)
	??0DTraceCoreMediaSWriter@@QAE@XZ @ 44 NONAME ; DTraceCoreMediaSWriter::DTraceCoreMediaSWriter(void)
	?UnregisterNotificationReceiver@MTraceCoreNotificationReceiver@@QAEXKJ@Z @ 45 NONAME ; void MTraceCoreNotificationReceiver::UnregisterNotificationReceiver(unsigned long, long)
	??1DTraceCoreMediaPlugin@@UAE@XZ @ 46 NONAME ; DTraceCoreMediaPlugin::~DTraceCoreMediaPlugin(void)
	??0DTraceCoreSettings@@QAE@XZ @ 47 NONAME ; DTraceCoreSettings::DTraceCoreSettings(void)
	??0MTraceCoreNotificationReceiver@@QAE@XZ @ 48 NONAME ; MTraceCoreNotificationReceiver::MTraceCoreNotificationReceiver(void)
	?WriteEnd@DTraceCoreWriter@@UAEXABVTWriteEndParams@@@Z @ 49 NONAME ; void DTraceCoreWriter::WriteEnd(class TWriteEndParams const &)
	?PreviousTraceDropped@DTraceCore@@QBEHXZ @ 50 NONAME ; int DTraceCore::PreviousTraceDropped(void) const
	?SetPreviousTraceDropped@DTraceCore@@QAEXH@Z @ 51 NONAME ; void DTraceCore::SetPreviousTraceDropped(int)
	?TraceDropped@DTraceCoreWriter@@QAEXH@Z @ 52 NONAME ; void DTraceCoreWriter::TraceDropped(int)
	?WasLastTraceDropped@DTraceCoreWriter@@QBEHXZ @ 53 NONAME ; int DTraceCoreWriter::WasLastTraceDropped(void) const
	?CreateInstance@DTraceCore@@SAPAV1@XZ @ 54 NONAME ; class DTraceCore * DTraceCore::CreateInstance(void)
	?RefreshActivations@DTraceActivationIf@@SAHXZ @ 55 NONAME ; int DTraceActivationIf::RefreshActivations(void)
	?GetCurrentWriterType@DTraceCore@@QAEHXZ @ 56 NONAME ; int DTraceCore::GetCurrentWriterType(void)
	?AbleToWrite@DTraceCoreWriter@@UAEHI@Z @ 57 NONAME ; int DTraceCoreWriter::AbleToWrite(unsigned int)
	?GetActiveWriter@DTraceCore@@QAEPAVDTraceCoreWriter@@XZ @ 58 NONAME ; class DTraceCoreWriter * DTraceCore::GetActiveWriter(void)

